# Generated by Django 3.1.5 on 2021-01-15 23:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_postalcodes_mexico', '0002_auto_20210115_2156'),
    ]

    operations = [
        migrations.AlterField(
            model_name='postalcode',
            name='d_zona',
            field=models.CharField(choices=[('Urbano', 'Urbano'), ('Rural', 'Rural'), ('Semiurbano', 'Semiurbano')], max_length=10, verbose_name='Tipo de Zona'),
        ),
    ]
